pub struct Config<const CONDITIONAL_LAYER_COUNT: usize = 0> {
pub sticky_timeout: Option<u16>,
pub conditional_layers: Slice<ConditionalLayer, CONDITIONAL_LAYER_COUNT>,
}Expand description
Configuration for layered keys / sticky layers / conditional layers.
Fields
sticky_timeout: Option<u16>Timeout (ms) after which an unused sticky layer deactivates.
When None, sticky layers stay active until another key is used.
The timeout starts when a sticky layer modifier is released without interruption (sticky committed). If another key is pressed while sticky is active, the timeout is cancelled / ignored.
conditional_layers: Slice<ConditionalLayer, CONDITIONAL_LAYER_COUNT>Rules that activate a then-layer when all of their if-layers are active.
Implementations